# SPDX-FileCopyrightText: 2017-present linuxdaemon <linuxdaemon.irc@gmail.com>
#
# SPDX-License-Identifier: MIT

"""IRC parser and utility library."""

from irclib._version import (
    __version__,
    __version_tuple__,
    version,
    version_tuple,
)

__all__ = ["__version__", "__version_tuple__", "version", "version_tuple"]
